blackmagicsorcery
==================================================
**Module**: :mod:`espressodb.base.utilities.blackmagicsorcery`


.. automodule:: espressodb.base.utilities.blackmagicsorcery
    :members:
    :special-members:
